@@ -16,13 +16,15 @@ The only onterface function is iter_avro, example usage::
 '''
 
 __all__ = [ 'iter_avro', 'reader']
-__version__ = '0.7.4'
+__version__ = '0.7.5'
 
 
 try:
     from . import _reader
+    from . import _writer
 except ImportError as e:
     from . import reader as _reader
+    from . import writer as _writer
 
 reader = iter_avro = _reader.iter_avro
-
+write = _writer.write
